pub(crate) fn is_metric_name_col(column: &ColumnMetadata) -> boolExpand description
Returns true if the column is the metric name column.
pub(crate) fn is_metric_name_col(column: &ColumnMetadata) -> boolReturns true if the column is the metric name column.